@@ -1,7 +1,7 @@
 from .argument import Argument
 from .command import Command, command
-from .formatter import CommonFormatter, ManualFormatter
+from .formatter import Formatter, ManualFormatter
 from .metadata import version
 from .mixin import mixin
 from .option import Option
-from .parser import CommonParser, ParseError
+from .parser import Parser, ParseError
