@@ -3,10 +3,10 @@ import inspect
 from collections import OrderedDict
 from box.functools import cachedproperty
 from ..argument import Argument
-from ..formatter import CommonFormatter
+from ..formatter import Formatter
 from ..mixin import Mixin, mixin as decorate_mixin
 from ..option import Option
-from ..parser import CommonParser, ParseError
+from ..parser import Parser, ParseError
 from .decorator import command as decorate_command
 from .error import DelegateError
 from .metaclass import Metaclass
@@ -16,21 +16,21 @@ class Command(metaclass=Metaclass):
 
     # Public
 
-    meta_formatter = CommonFormatter
-    meta_parser = CommonParser
+    meta_formatter = Formatter
+    meta_parser = Parser
 
-    def __init__(self, *, name=None, stack=None, executor=None):
+    def __init__(self, *, name=None, stack=None, execute=None):
         if name is None:
             name = type(self).__name__.lower()
         if stack is None:
             stack = []
-        if executor is None:
-            executor = self.__execute__
-        if executor.__doc__:
-            self.__doc__ = executor.__doc__
+        if execute is None:
+            execute = self.__execute__
+        if execute.__doc__:
+            self.__doc__ = execute.__doc__
         self.__name = name
         self.__stack = stack
-        self.__executor = executor
+        self.__execute = execute
 
     def __getattr__(self, name):
         if not name.startswith('_'):
@@ -76,7 +76,7 @@ class Command(metaclass=Metaclass):
             result = self.meta_parse(argv)
             self.__update(result.options)
             self.__mixin()
-            self.__executor(*result.arguments)
+            self.__execute(*result.arguments)
         except (ParseError, Exception) as exception:
             self.__mixin(exception)
             self.__error(exception)
@@ -116,7 +116,7 @@ class Command(metaclass=Metaclass):
     @cachedproperty
     def __arguments(self):
         arguments = OrderedDict()
-        signature = inspect.signature(self.__executor)
+        signature = inspect.signature(self.__execute)
         for name, item in signature.parameters.items():
             if isinstance(item.annotation, Argument):
                 arguments[name] = item.annotation
@@ -195,15 +195,15 @@ class Command(metaclass=Metaclass):
     def __subcommands(self):
         subcommands = OrderedDict()
         for command, name, value in self.__attributes.values():
-            executor = None
+            execute = None
             if command is not self:
                 continue
             if getattr(value, decorate_command.marker, False):
                 value = Command
-                executor = getattr(command, name)
+                execute = getattr(command, name)
             if (isinstance(value, type) and
                 issubclass(value, Command)):
-                value = value(name=name, stack=self.__stack, executor=executor)
+                value = value(name=name, stack=self.__stack, execute=execute)
             if isinstance(value, Command):
                 subcommands[name] = value
         return subcommands
