@@ -1,9 +1,9 @@
 from jinja2 import PackageLoader
 from box.functools import cachedproperty
-from .common import CommonFormatter
+from .formatter import Formatter
 
 
-class ManualFormatter(CommonFormatter):
+class ManualFormatter(Formatter):
 
     # Public
 
